import objectdraw.*;

/**
   Main controller class for Flowers lab

   This program will create a new Flower each time the mouse is
   pressed on the canvas.  As the mouse is dragged, the Flower is
   instructed to grow.  If the mouse is pressed again on the most
   recently created Flower, it will be instructed to change its color.

   Note: You should not make any modifications to this class.

   Implementation from Bruce, Danyluk, Murtagh, Williams College

   Formatted and documented by Jim Teresco, Siena College, for
   CSIS 120 Labs, Spring 2011.
   Further updated by Jim Teresco for CSC 252, The College of Saint Rose,
   Fall 2014.

   $Id: Spring.java 2425 2014-09-12 20:31:07Z terescoj $
*/

public class Spring extends WindowController {
    
    /* a couple of constants to help determine flower heights */
    public static final int BASE_HEIGHT = 50;
    public static final double GROW_FRAC = 0.333;

    /* Remember the most recently created flower */
    private Flower newestFlower;
        
    /* Create a new flower or change the color of the last flower */
    public void onMousePress(Location point) {

        if (newestFlower != null && newestFlower.flowerContains(point)) {
            newestFlower.changeColor();
        } 
        else {
            newestFlower = 
		new Flower(point, BASE_HEIGHT+point.getY()*GROW_FRAC, canvas);
        }
    }
    
    /* Make the newest flower grow a little as the mouse is dragged */
    public void onMouseDrag(Location point) {

        if (newestFlower != null) {
            newestFlower.grow();
        }
    }
    
    /* Clear the canvas to start again when the mouse moves into the window */
    public void onMouseEnter(Location pt) {

        canvas.clear();
        newestFlower = null;
    }
}
